@@ -88,6 +88,26 @@ static void createXmlFile(QFile &file, int version, int flags, const QByteArray
     file.write("</" + toplevelTag + ">\n");
 }
 
+class ShortcutSchemeHandler
+{
+public:
+    ShortcutSchemeHandler(const QString &scheme)
+        : cgScheme(KSharedConfig::openConfig(), QStringLiteral("Shortcut Schemes"))
+        , prevScheme(cgScheme.readEntry("Current Scheme", QStringLiteral("Default")))
+    {
+        cgScheme.writeEntry("Current Scheme", scheme);
+    }
+
+    ~ShortcutSchemeHandler()
+    {
+        cgScheme.writeEntry("Current Scheme", prevScheme);
+    }
+
+private:
+    KConfigGroup cgScheme;
+    const QString prevScheme;
+};
+
 static void clickApply(KEditToolBar *dialog)
 {
     QDialogButtonBox *box = dialog->findChild<QDialogButtonBox *>();
@@ -106,6 +126,15 @@ void KXmlGui_UnitTest::initTestCase()
         QFile::remove(configFile);
         KSharedConfig::openConfig()->reparseConfiguration();
     }
+
+    // Create "Test" shortcut scheme to eliminate the KF warning
+    QFile testScheme = QFile(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
+        + QLatin1String("/%1/shortcuts/%2").arg(QCoreApplication::applicationName(), QStringLiteral("Test")));
+    if (!testScheme.exists()) {
+        QVERIFY(QFileInfo(testScheme).dir().mkpath(QStringLiteral(".")));
+        QVERIFY(testScheme.open(QIODevice::WriteOnly));
+        testScheme.write(QByteArray("<gui><ActionProperties/></gui>"));
+    }
 }
 
 void KXmlGui_UnitTest::testFindVersionNumber_data()
@@ -457,6 +486,56 @@ void KXmlGui_UnitTest::testPartMerging()
     factory.removeClient(&hostClient);
 }
 
+void KXmlGui_UnitTest::testShortcutSchemeMerging()
+{
+    TestGuiClient client;
+
+    ShortcutSchemeHandler sss(QStringLiteral("Test"));
+
+    KActionCollection *ac = client.actionCollection();
+
+    QAction *a = ac->addAction(QStringLiteral("test_action"));
+    ac->setDefaultShortcut(a, QKeySequence(QStringLiteral("Ctrl+A")));
+
+    const QByteArray appXml = R"(<?xml version = "1.0"?>
+<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
+<kpartgui name="foo" version="5">
+<MenuBar>
+  <Menu name="file"><text>&amp;File</text>
+    <Action name="test_action" />
+  </Menu>
+</MenuBar></kpartgui>
+)";
+    client.createGUI(appXml, false);
+
+    const QByteArray settingsXml = R"(<!DOCTYPE kpartgui SYSTEM 'kpartgui.dtd'>
+<kpartgui name="foo" version="1">
+ <MenuBar>
+  <Menu name="file">
+   <text>&amp;File</text>
+   <Action name="test_action" />
+  </Menu>
+ </MenuBar>
+ <ActionProperties scheme="Default">
+  <Action name="test_action" shortcut="Ctrl+B"/>
+ </ActionProperties>
+ <ActionProperties scheme="Test">
+  <Action name="test_action" shortcut="Ctrl+C"/>
+ </ActionProperties>
+</kpartgui>
+)";
+    client.mergeXML(settingsXml);
+
+    KMainWindow mainWindow;
+    KXMLGUIBuilder builder(&mainWindow);
+    KXMLGUIFactory factory(&builder);
+    factory.addClient(&client);
+
+    QCOMPARE(a->shortcut(), QKeySequence(QStringLiteral("Ctrl+C")));
+
+    factory.removeClient(&client);
+}
+
 void KXmlGui_UnitTest::testPartMergingSettings() // #252911
 {
     const QByteArray hostXml =
@@ -662,7 +741,7 @@ void KXmlGui_UnitTest::testActionListAndSeparator()
 
     QAction *action1 = new QAction(this);
     action1->setObjectName(QStringLiteral("action1"));
-    client.actionCollection()->setDefaultShortcut(action1, QKeySequence(QStringLiteral("Ctrl+2")));
+    KActionCollection::setDefaultShortcut(action1, QKeySequence(QStringLiteral("Ctrl+2")));
     QAction *action2 = new QAction(this);
     action2->setObjectName(QStringLiteral("action2"));
     const QList<QAction *> actionList = {action1, action2};
@@ -723,7 +802,7 @@ void KXmlGui_UnitTest::testHiddenToolBar()
         "  <Action name=\"go_up\"/>\n"
         "</ToolBar>\n"
         "</gui>\n";
-    KConfigGroup cg(KSharedConfig::openConfig(), "testHiddenToolBar");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("testHiddenToolBar"));
     TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.setAutoSaveSettings(cg);
     mainWindow.createActions(QStringList() << QStringLiteral("go_up"));
@@ -768,7 +847,7 @@ void KXmlGui_UnitTest::testCustomPlaceToolBar()
         "  <Action name=\"help_about_kde\"/>\n"
         "</ToolBar>\n"
         "</gui>\n";
-    KConfigGroup cg(KSharedConfig::openConfig(), "testHiddenToolBar");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("testHiddenToolBar"));
     TestXmlGuiWindow mw(xml, "kxmlgui_unittest.rc");
     mw.setAutoSaveSettings(cg);
 
@@ -820,7 +899,7 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
         "</gui>\n";
     {
         // do not interfere with the "toolbarVisibility" unit test
-        KConfigGroup cg(KSharedConfig::openConfig(), "testAutoSaveSettings");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("testAutoSaveSettings"));
         TestXmlGuiWindow mw(xml, "kxmlgui_unittest.rc");
         mw.show();
         mw.setAutoSaveSettings(cg);
@@ -855,7 +934,7 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
     }
 
     {
-        KConfigGroup cg(KSharedConfig::openConfig(), "testAutoSaveSettings");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("testAutoSaveSettings"));
         TestXmlGuiWindow mw2(xml, "kxmlgui_unittest.rc");
         mw2.show();
         mw2.setAutoSaveSettings(cg);
@@ -899,7 +978,7 @@ void KXmlGui_UnitTest::testDeletedContainers() // deleted="true"
         "  <Action name=\"go_up\"/>\n"
         "</ToolBar>\n"
         "</gui>\n";
-    KConfigGroup cg(KSharedConfig::openConfig(), "testDeletedToolBar");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("testDeletedToolBar"));
     TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.setAutoSaveSettings(cg);
     mainWindow.createActions(QStringList() << QStringLiteral("go_up") << QStringLiteral("file_new") << QStringLiteral("game_new"));
@@ -1103,8 +1182,8 @@ void KXmlGui_UnitTest::testShortcuts()
     KXMLGUIFactory factory(&builder);
     factory.addClient(&client);
 
-    QAction *actionOpen = client.action("file_open");
-    QAction *actionQuit = client.action("file_quit");
+    QAction *actionOpen = client.action(QStringLiteral("file_open"));
+    QAction *actionQuit = client.action(QStringLiteral("file_quit"));
     QVERIFY(actionOpen && actionQuit);
     QCOMPARE(actionOpen->shortcuts(), QList<QKeySequence>() << QKeySequence(QStringLiteral("Ctrl+O")));
     // #345411
@@ -1204,3 +1283,5 @@ void KXmlGui_UnitTest::testSaveShortcutsAndRefresh()
     a = client.actionCollection()->action(QStringLiteral("file_open"));
     QCOMPARE(a->shortcut(), QKeySequence(Qt::Key_F22));
 }
+
+#include "moc_kxmlgui_unittest.cpp"
